@@ -51,11 +51,12 @@ struct _RsttoMainWindowPriv
     } containers;
 
     struct {
-        GtkOrientation thumbnail_viewer_orientation;
-        gboolean       thumbnail_viewer_visibility;
-        gboolean       toolbar_visibility;
-        gint           max_cache_size;
-        gdouble        slideshow_timeout;
+        GtkOrientation  thumbnail_viewer_orientation;
+        gboolean        thumbnail_viewer_visibility;
+        gboolean        toolbar_visibility;
+        gint            max_cache_size;
+        gdouble         slideshow_timeout;
+        const GdkColor *bg_color;
     } settings;
 
     struct {
@@ -238,6 +239,9 @@ cb_rstto_main_window_about(GtkWidget *widget, RsttoMainWindow *window);
 static void
 cb_rstto_main_window_preferences(GtkWidget *widget, RsttoMainWindow *window);
 
+static void
+cb_rstto_bg_color_override_check_toggled(GtkToggleButton *button, GtkWidget *);
+
 static void
 cb_rstto_main_window_nav_iter_changed(RsttoNavigator *navigator, gint nr, RsttoNavigatorEntry *entry, RsttoMainWindow *window);
 static void
@@ -456,6 +460,19 @@ rstto_main_window_init(RsttoMainWindow *window)
     window->priv->menus.view.rotate.menu_item_rotate_cw = gtk_image_menu_item_new_with_mnemonic(_("Rotate _Right"));
     window->priv->menus.view.rotate.menu_item_rotate_ccw = gtk_image_menu_item_new_with_mnemonic(_("Rotate _Left"));
 
+    gtk_widget_add_accelerator(window->priv->menus.view.rotate.menu_item_rotate_cw,
+                               "activate",
+                               accel_group,
+                               GDK_bracketright,
+                               GDK_CONTROL_MASK,
+                               GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(window->priv->menus.view.rotate.menu_item_rotate_ccw,
+                               "activate",
+                               accel_group,
+                               GDK_bracketleft,
+                               GDK_CONTROL_MASK,
+                               GTK_ACCEL_VISIBLE);
+
     gtk_menu_shell_append(GTK_MENU_SHELL(window->priv->menus.view.rotate.menu),
             window->priv->menus.view.rotate.menu_item_rotate_cw);
     gtk_menu_shell_append(GTK_MENU_SHELL(window->priv->menus.view.rotate.menu),
@@ -1067,6 +1084,12 @@ cb_rstto_main_window_key_press_event(GtkWidget *widget, GdkEventKey *event, gpoi
                 rstto_main_window_set_show_thumbnail_viewer(RSTTO_MAIN_WINDOW(window),
                         !(RSTTO_MAIN_WINDOW(window)->priv->settings.thumbnail_viewer_visibility));
                 break;
+            case GDK_bracketleft:
+                cb_rstto_main_window_rotate_ccw(NULL, RSTTO_MAIN_WINDOW(window));
+                break;
+            case GDK_bracketright:
+                cb_rstto_main_window_rotate_cw(NULL, RSTTO_MAIN_WINDOW(window));
+                break;
         }
     }
     return TRUE;
@@ -1084,15 +1107,16 @@ cb_rstto_main_window_state_event(GtkWidget *widget, GdkEventWindowState *event,
             gtk_widget_hide(window->priv->toolbar.bar);
             gtk_widget_hide(window->priv->statusbar);
             GdkColor *color = g_new0(GdkColor, 1);
-            color->pixel = 0;
 
             rstto_picture_viewer_set_bg_color(RSTTO_PICTURE_VIEWER(window->priv->picture_viewer), color);
+
+            g_free(color);
         }
         else
         {
             gtk_widget_show(window->priv->menus.menu);
             gtk_widget_show(window->priv->statusbar);
-            rstto_picture_viewer_set_bg_color(RSTTO_PICTURE_VIEWER(window->priv->picture_viewer), NULL);
+            rstto_picture_viewer_set_bg_color(RSTTO_PICTURE_VIEWER(window->priv->picture_viewer), window->priv->settings.bg_color);
 
             if (window->priv->settings.toolbar_visibility == TRUE)
             {
@@ -1125,6 +1149,15 @@ cb_rstto_main_window_pause(GtkWidget *widget, RsttoMainWindow *window)
 static void
 cb_rstto_main_window_preferences(GtkWidget *widget, RsttoMainWindow *window)
 {
+    GdkColor  *color = NULL;
+    if (rstto_picture_viewer_get_bg_color(RSTTO_PICTURE_VIEWER(window->priv->picture_viewer)))
+    {
+        color = gdk_color_copy(rstto_main_window_get_pv_bg_color(window));
+    }
+    GtkWidget *slideshow_main_vbox;
+    GtkWidget *slideshow_main_lbl;
+    GtkWidget *display_main_vbox;
+    GtkWidget *display_main_lbl;
     GtkWidget *dialog = xfce_titled_dialog_new_with_buttons(_("Image viewer Preferences"),
                                                     GTK_WINDOW(window),
                                                     GTK_DIALOG_NO_SEPARATOR,
@@ -1141,9 +1174,41 @@ cb_rstto_main_window_preferences(GtkWidget *widget, RsttoMainWindow *window)
 
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), notebook,  TRUE, TRUE, 0);
 
-    GtkWidget *main_vbox = gtk_vbox_new(FALSE, 0);
-    GtkWidget *main_lbl = gtk_label_new(_("Slideshow"));
-    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), main_vbox, main_lbl);
+    slideshow_main_vbox = gtk_vbox_new(FALSE, 0);
+    slideshow_main_lbl = gtk_label_new(_("Slideshow"));
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), slideshow_main_vbox, slideshow_main_lbl);
+
+    display_main_vbox = gtk_vbox_new(FALSE, 0);
+    display_main_lbl = gtk_label_new(_("Display"));
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), display_main_vbox, display_main_lbl);
+
+    GtkWidget *bg_color_vbox = gtk_vbox_new(FALSE, 0);
+    GtkWidget *bg_color_frame = xfce_create_framebox_with_content (_("Background Color"), bg_color_vbox);
+
+    GtkWidget *bg_color_override_check = gtk_check_button_new_with_mnemonic(_("_Override Background Color:"));
+    GtkWidget *bg_hbox = gtk_hbox_new(FALSE, 4);
+    GtkWidget *bg_color_button = gtk_color_button_new();
+    gtk_box_pack_start(GTK_BOX(bg_hbox), bg_color_override_check, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(bg_hbox), bg_color_button, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(bg_color_vbox), bg_hbox, FALSE, FALSE, 0);
+
+    g_signal_connect(G_OBJECT(bg_color_override_check), "toggled", (GCallback)cb_rstto_bg_color_override_check_toggled, bg_color_button);
+
+    if (color)
+    {
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bg_color_override_check), TRUE);
+        gtk_color_button_set_color(GTK_COLOR_BUTTON(bg_color_button), color);
+        gdk_color_free(color);
+        color = NULL;
+    }
+    else
+    {
+        gtk_widget_set_sensitive(bg_color_button, FALSE);
+    }
+
+    gtk_container_set_border_width (GTK_CONTAINER (bg_color_frame), 8);
+
+    gtk_box_pack_start(GTK_BOX(display_main_vbox), bg_color_frame, FALSE, TRUE, 0);
 
     GtkWidget *slideshow_vbox = gtk_vbox_new(FALSE, 0);
     GtkWidget *slideshow_frame = xfce_create_framebox_with_content (_("Timeout"), slideshow_vbox);
@@ -1154,7 +1219,7 @@ cb_rstto_main_window_preferences(GtkWidget *widget, RsttoMainWindow *window)
     gtk_container_set_border_width (GTK_CONTAINER (slideshow_frame), 8);
     gtk_container_set_border_width (GTK_CONTAINER (preload_frame), 8);
 
-    GtkWidget *slideshow_lbl = gtk_label_new(_("The time individual images are displayed during a slideshow\n(in seconds)"));
+    GtkWidget *slideshow_lbl = gtk_label_new(_("The time period an individual image is displayed during a slideshow\n(in seconds)"));
     GtkWidget *slideshow_hscale = gtk_hscale_new_with_range(1, 60, 1);
 
 
@@ -1177,8 +1242,8 @@ cb_rstto_main_window_preferences(GtkWidget *widget, RsttoMainWindow *window)
     gtk_box_pack_start(GTK_BOX(preload_vbox), preload_lbl, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(preload_vbox), preload_check, FALSE, TRUE, 0);
 
-    gtk_box_pack_start(GTK_BOX(main_vbox), slideshow_frame, FALSE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(main_vbox), preload_frame, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(slideshow_main_vbox), slideshow_frame, FALSE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(slideshow_main_vbox), preload_frame, FALSE, TRUE, 0);
 
     gtk_widget_show_all(notebook);
 
@@ -1189,6 +1254,17 @@ cb_rstto_main_window_preferences(GtkWidget *widget, RsttoMainWindow *window)
         case GTK_RESPONSE_OK:
             rstto_main_window_set_slideshow_timeout(window, gtk_range_get_value(GTK_RANGE(slideshow_hscale)) * 1000);
             window->priv->navigator->preload = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(preload_check));
+            if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bg_color_override_check)) == TRUE)
+            {
+                GdkColor *new_color = g_new0(GdkColor, 1);
+                gtk_color_button_get_color(GTK_COLOR_BUTTON(bg_color_button), new_color);
+                rstto_main_window_set_pv_bg_color(window, new_color);
+                g_free(new_color);
+            }
+            else
+            {
+                rstto_main_window_set_pv_bg_color(window, NULL);
+            }
         default:
             break;
     }
@@ -1754,3 +1830,38 @@ cb_rstto_main_window_spawn_app(GtkWidget *widget, ThunarVfsMimeApplication *app)
     GList *list = g_list_prepend(NULL, info->path);
     thunar_vfs_mime_handler_exec(THUNAR_VFS_MIME_HANDLER(app), NULL, list, NULL);
 }
+
+void
+rstto_main_window_set_pv_bg_color (RsttoMainWindow *window, const GdkColor *color)
+{
+    rstto_picture_viewer_set_bg_color(RSTTO_PICTURE_VIEWER(window->priv->picture_viewer), color);
+    if (color)
+    {
+        window->priv->settings.bg_color = gdk_color_copy(color);
+    }
+    else
+    {
+        window->priv->settings.bg_color = NULL;
+    }
+}
+
+const GdkColor *
+rstto_main_window_get_pv_bg_color (RsttoMainWindow *window)
+{
+    /*return rstto_picture_viewer_get_bg_color(RSTTO_PICTURE_VIEWER(window->priv->picture_viewer));*/
+    return window->priv->settings.bg_color;
+}
+
+static void
+cb_rstto_bg_color_override_check_toggled(GtkToggleButton *button, GtkWidget *widget)
+{
+    if (gtk_toggle_button_get_active(button) == TRUE)
+    {
+        gtk_widget_set_sensitive(widget, TRUE);
+    }
+    else
+    {
+        gtk_widget_set_sensitive(widget, FALSE);
+
+    }
+}
