@@ -1056,7 +1056,7 @@ rstto_picture_viewer_set_menu (RsttoPictureViewer *viewer, GtkMenu *menu)
 }
 
 void
-rstto_picture_viewer_set_bg_color (RsttoPictureViewer *viewer, GdkColor *color)
+rstto_picture_viewer_set_bg_color (RsttoPictureViewer *viewer, const GdkColor *color)
 {
     if (viewer->priv->bg_color)
     {
@@ -1066,5 +1066,13 @@ rstto_picture_viewer_set_bg_color (RsttoPictureViewer *viewer, GdkColor *color)
     if (color)
     {
         viewer->priv->bg_color = gdk_color_copy(color);
+        GdkColormap *colormap = gtk_widget_get_colormap(GTK_WIDGET(viewer));
+        gdk_colormap_alloc_color(colormap, viewer->priv->bg_color, TRUE, TRUE);
     }
 }
+
+const GdkColor *
+rstto_picture_viewer_get_bg_color (RsttoPictureViewer *viewer)
+{
+    return viewer->priv->bg_color;
+}
